@@ -9,3 +9,8 @@ NO_MATCHING_EVENT_FOUND = "No Matching Event Found"
 
 DEFAULT_IP = "127.0.0.1"
 DEFAULT_PORT = 8080
+
+DEFAULT_REQUEST_TIMEOUT = 1
+DEFAULT_POLL_INTERVAL = 0.1
+DEFAULT_MAXIMUM_POLL_TIME = 1
+DEFAULT_UNEXPECTED_EVENT_MAXIMUM_POLL_TIME = 1
