@@ -7,6 +7,12 @@ class TesLibError(RuntimeError):
     pass
 
 
+class ExpectationError(AssertionError):
+    """Raised when the provided expectations are not valid"""
+
+    pass
+
+
 class EventNotFoundError(AssertionError):
     """Raised when an expected event was not found"""
 
