@@ -8,9 +8,16 @@ from multiprocessing import connection
 import requests
 import logging
 
+from .defaults import (
+    get_default_on_failure,
+    get_default_request_timeout,
+    get_default_poll_interval,
+    get_default_maximum_poll_time,
+    get_default_unexpected_event_maximum_poll_time,
+)
 from .test_event import TestEvent
 from .expectation import Expectation
-from .errors import TesLibError, EventNotFoundError, UnexpectedEventFoundError
+from .errors import TesLibError, EventNotFoundError, UnexpectedEventFoundError, ExpectationError
 from .library_settings import _TesLibInstance
 from .messages import (
     GetAllEventsMessage,
@@ -25,31 +32,38 @@ from .constants import EVENT_SOURCE_KEY, EVENT_TYPE_KEY, EVENT_ID_KEY, EVENT_STA
 from .constants import DEFAULT_IP, DEFAULT_PORT, NO_MATCHING_EVENT_FOUND
 
 
-def wait_for_response(context: str, recv_connection: connection.Connection, timeout=0.5) -> Any:
+def wait_for_response(context: str, recv_connection: connection.Connection) -> Any:
 
-    if recv_connection.poll(timeout=timeout):
+    if recv_connection.poll(timeout=get_default_request_timeout()):
         result = recv_connection.recv()
     else:
-        logging.warning(f"No message received from event store, context: {context}")
+        logging.warning(
+            "No message received from event store, the request_timeout may need increasing"
+            f" in the initialise call, context: {context}",
+        )
         raise TesLibError(f"No response from event store, context: {context}")
     return result
 
 
-def get_all_events(timeout: int = 1) -> List[Dict]:
+def get_all_events() -> List[Dict]:
     """Get all events currently in the event store
 
-    :param timeout: The amount of time to give the event store to return all the events
     :return: A list of events
     """
     tes_lib = _TesLibInstance.get_instance()
 
     tes_lib.queue.put(GetAllEventsMessage())
 
-    result = wait_for_response("get_all_events", tes_lib.parent_conn, timeout=timeout)
+    result = wait_for_response("get_all_events", tes_lib.parent_conn)
 
     return result
 
 
+def _check_expectations(expectations: List[Expectation]):
+    if expectations is None or len(expectations) < 1:
+        raise ExpectationError(f"The provided expectation list of '{expectations}' is not valid")
+
+
 def _event_matches_expectations(event: Dict, expectations: List[Expectation]) -> bool:
     for expectation in expectations:
         if expectation.event_field_name not in event:
@@ -122,7 +136,26 @@ def _log_event_store(
     for event in events:
         event_id = event[EVENT_ID_KEY]
         del event[EVENT_ID_KEY]
-        logging.info(f"event_id: {event_id}, {dict(sorted(event.items()))}")
+
+        # Log the event fields first, helps when trying to find an expected event where the
+        # expectations are not quite correct.
+        ordered_fields = {}
+        if EVENT_SOURCE_KEY in event:
+            ordered_fields[EVENT_SOURCE_KEY] = event[EVENT_SOURCE_KEY]
+            del event[EVENT_SOURCE_KEY]
+
+        if EVENT_STATE_KEY in event:
+            ordered_fields[EVENT_STATE_KEY] = event[EVENT_STATE_KEY]
+            del event[EVENT_STATE_KEY]
+
+        if EVENT_TYPE_KEY in event:
+            ordered_fields[EVENT_TYPE_KEY] = event[EVENT_TYPE_KEY]
+            del event[EVENT_TYPE_KEY]
+
+        ordered_fields = dict(sorted(ordered_fields.items()))
+        ordered_fields.update(dict(sorted(event.items())))
+
+        logging.info(f"event_id: {event_id}, {ordered_fields}")
 
     logging.info("***** End Of Event Store *****")
 
@@ -146,7 +179,7 @@ def log_full_event_store(
 
     tes_lib.queue.put(GetFullEventLogMessage())
 
-    events = wait_for_response("log_full_event_store", tes_lib.parent_conn, timeout=5)
+    events = wait_for_response("log_full_event_store", tes_lib.parent_conn)
 
     _log_event_store(
         events,
@@ -199,23 +232,33 @@ def log_event_store(
 
 def expect_event(
     expectations: List[Expectation],
-    timeout: float = 5,
-    poll_interval: float = 0.1,
-    on_failure: Callable = log_event_store,
+    maximum_poll_time: float = 0,
+    poll_interval: float = 0,
+    on_failure: Callable = None,
 ) -> Dict:
     """Expect an event - finds the first event that matches all the given expectations in the
     event store. This event is then removed from the event store and returned.
 
     :param expectations: The list of expectations the event must meet
-    :param timeout: The amount of time to wait for the event
-    :param poll_interval: The time between polling for the event
-    :param on_failure: The function to call when we fail to find the expected event
+    :param maximum_poll_time: The amount of time to wait for the event to be found, if not
+      provided the default will be used
+    :param poll_interval: The time between polling for the event, if not provided the default
+      will be used
+    :param on_failure: The function to call when we fail to find the expected event, if not
+      provided the default will be used
     :return: The found event
     :raises EventNotFoundError: The expected event was not found
     """
+    _check_expectations(expectations)
     returned_event: Any = NO_MATCHING_EVENT_FOUND
 
-    end_time = time.time() + timeout
+    if maximum_poll_time <= 0:
+        maximum_poll_time = get_default_maximum_poll_time()
+
+    if poll_interval <= 0:
+        poll_interval = get_default_poll_interval()
+
+    end_time = time.time() + maximum_poll_time
     tes_lib = _TesLibInstance.get_instance()
 
     while returned_event is NO_MATCHING_EVENT_FOUND and time.time() < end_time:
@@ -231,6 +274,9 @@ def expect_event(
         tes_lib.queue.put(RemoveExpectedEventMessage(returned_event))
 
     if returned_event == NO_MATCHING_EVENT_FOUND:
+        if on_failure is None:
+            on_failure = get_default_on_failure()
+
         on_failure()
         raise EventNotFoundError(
             f"Failed to find an event matching the following expectations: {expectations}"
@@ -239,19 +285,30 @@ def expect_event(
     return returned_event
 
 
-def dont_expect_event(expectations: List[Expectation], timeout: float, poll_interval: float = 0.1):
+def dont_expect_event(
+    expectations: List[Expectation], maximum_poll_time: float = 0, poll_interval: float = 0
+):
     """Don't expect any events in the event store matching the given expectations
 
     :param expectations: The list of expectations to match against
-    :param timeout: The amount of time to wait without seeing the event
-    :param poll_interval: The time between polling for the event
+    :param maximum_poll_time: The amount of time to wait without seeing the event, if
+      not provided the default will be used
+    :param poll_interval: The time between polling for the event, if not provided the default
+                          will be used
     :return: None
     :raises UnexpectedEventFoundError: An unexpected event was found that matches the given
             expectations
     """
+    _check_expectations(expectations)
     returned_event = NO_MATCHING_EVENT_FOUND
 
-    end_time = time.time() + timeout
+    if maximum_poll_time <= 0:
+        maximum_poll_time = get_default_unexpected_event_maximum_poll_time()
+
+    if poll_interval <= 0:
+        poll_interval = get_default_poll_interval()
+
+    end_time = time.time() + maximum_poll_time
     tes_lib = _TesLibInstance.get_instance()
 
     while returned_event is NO_MATCHING_EVENT_FOUND and time.time() < end_time:
@@ -271,23 +328,33 @@ def dont_expect_event(expectations: List[Expectation], timeout: float, poll_inte
 
 def get_event(
     expectations: List[Expectation],
-    timeout: float = 5,
-    poll_interval: float = 0.1,
-    on_failure: Callable = log_event_store,
+    maximum_poll_time: float = 0,
+    poll_interval: float = 0,
+    on_failure: Callable = None,
 ) -> Dict:
     """Get an event - finds the first event that matches all the given expectations in the
     event store.
 
     :param expectations: The list of expectations the event must meet
-    :param timeout: The amount of time to wait for the event
-    :param poll_interval: The time between polling for the event
-    :param on_failure: The function to call when we fail to find the event
+    :param maximum_poll_time: The amount of time to wait for the event to be found, if not
+      provided the default will be used
+    :param poll_interval: The time between polling for the event, if not provided the default
+      will be used
+    :param on_failure: The function to call when we fail to find the event, if not provided the
+      default will be used
     :return: The found event
     :raises EventNotFoundError: The event was not found
     """
+    _check_expectations(expectations)
     returned_event: Any = NO_MATCHING_EVENT_FOUND
 
-    end_time = time.time() + timeout
+    if maximum_poll_time <= 0:
+        maximum_poll_time = get_default_maximum_poll_time()
+
+    if poll_interval <= 0:
+        poll_interval = get_default_poll_interval()
+
+    end_time = time.time() + maximum_poll_time
     tes_lib = _TesLibInstance.get_instance()
 
     while returned_event is NO_MATCHING_EVENT_FOUND and time.time() < end_time:
@@ -299,6 +366,9 @@ def get_event(
             time.sleep(poll_interval)
 
     if returned_event == NO_MATCHING_EVENT_FOUND:
+        if on_failure is None:
+            on_failure = get_default_on_failure()
+
         on_failure()
         raise EventNotFoundError(
             f"Failed to find an event matching the following expectations: {expectations}"
@@ -307,35 +377,38 @@ def get_event(
     return returned_event
 
 
-def get_all_matching_events(expectations: List[Expectation], timeout: float = 1) -> List[Dict]:
+def get_all_matching_events(expectations: List[Expectation]) -> List[Dict]:
     """Get all events from the store that match the given expectations
 
     :param expectations: The list of expectations the event must meet
-    :param timeout: The amount of time to wait for the event
+    :param timeout: The amount of time to wait for the matching events to be returned
     :param poll_interval: The time between polling for the event
     :return: A list of the events found
     """
+    _check_expectations(expectations)
     tes_lib = _TesLibInstance.get_instance()
     tes_lib.queue.put(GetAllMatchingEventsMessage(expectations))
 
-    events = wait_for_response("get_all_matching_events", tes_lib.parent_conn, timeout=timeout)
+    events = wait_for_response("get_all_matching_events", tes_lib.parent_conn)
 
     return events
 
 
-def delete_all_matching_events(expectations: List[Expectation], timeout: float = 1) -> int:
+def delete_all_matching_events(expectations: List[Expectation]) -> int:
     """Delete all events from the store that match the given expectations
 
     :param expectations: The list of expectations the event must meet
-    :param timeout: The amount of time to wait for the event
+    :param timeout: The amount of time to wait for the matching events to be deleted
     :param poll_interval: The time between polling for the event
     :return: The number of events deleted
     """
+    _check_expectations(expectations)
     tes_lib = _TesLibInstance.get_instance()
     tes_lib.queue.put(DeleteMatchingEventsMessage(expectations))
 
     num_events_removed = wait_for_response(
-        "delete_all_matching_events", tes_lib.parent_conn, timeout=timeout
+        "delete_all_matching_events",
+        tes_lib.parent_conn,
     )
 
     return int(num_events_removed)
