@@ -3,9 +3,11 @@ The library settings and state
 """
 import time
 from multiprocessing import Queue, Pipe, Process
+from typing import Callable
 import requests
 import logging
 
+from .defaults import setup_library_defaults
 from .errors import TesLibError
 from .test_event_store import event_store_run_loop
 from .add_event_web_server import run_webserver
@@ -54,7 +56,7 @@ class _TesLib:
             "Failed to initialise library - no response from add event webserver before timeout"
         )
 
-    def initialise(self, ip_address: str, port: int):
+    def _initialise(self, ip_address: str, port: int):
         """Initialise the library
 
         :param ip_address: The ip_address the webserver should  listen on
@@ -78,6 +80,43 @@ class _TesLib:
 
         self._initialised = True
 
+    def initialise(
+        self,
+        ip_address: str,
+        port: int,
+        on_failure: Callable,
+        request_timeout: float,
+        poll_interval: float,
+        maximum_poll_time: float,
+        unexpected_event_maximum_poll_time: float,
+    ):
+        """Initialise the library
+
+        :param ip_address: The ip_address the webserver should  listen on
+        :param port: The port the webserver should listen on
+        :param on_failure: The default function to be called when an expectation failure occurs
+        :param request_timeout: The maximum amount of time to wait for a response from the event
+          store
+        :param poll_interval: How often to poll when repeatedly checking the event store
+        :param maximum_poll_time: The maximum amount of time to keep polling the event store
+          when repeatedly checking
+        :param unexpected_event_maximum_poll_time: The maximum amount of time to keep polling
+          the event store when repeatedly checking an event has not occurred
+        :return: None
+        """
+        if self._initialised:
+            return
+
+        setup_library_defaults(
+            on_failure,
+            poll_interval,
+            request_timeout,
+            maximum_poll_time,
+            unexpected_event_maximum_poll_time,
+        )
+
+        self._initialise(ip_address, port)
+
     def reset(self, timeout=5):
         """Reset the event store ready for the next test run
 
@@ -93,13 +132,13 @@ class _TesLib:
         from .event_helpers import wait_for_response
 
         try:
-            _ = wait_for_response("Reset test event store", self.parent_conn, timeout=timeout)
+            _ = wait_for_response("Reset test event store", self.parent_conn)
         except TesLibError:
             # If we don't get a response reset the library
             logging.error("No response from event store on reset - restarting processes")
 
             self.cleanup()
-            self.initialise(self.ip_address, self.port)
+            self._initialise(self.ip_address, self.port)
 
     def cleanup(self):
         """Cleanup the library
@@ -130,37 +169,3 @@ class _TesLibInstance:
         if _TesLibInstance.INSTANCE is None:
             _TesLibInstance.INSTANCE = _TesLib()
         return _TesLibInstance.INSTANCE
-
-
-def initialise(ip_address: str = DEFAULT_IP, port: int = DEFAULT_PORT):
-    """Initialise the library - this will start the event store and webserver processes. Each call
-    of initialise should be paired with a call to cleanup.
-
-    Calling this function multiple times without calling cleanup between will have no effect
-
-    :param ip_address: The IP address to be used by the add event webserver
-    :param port: The port to be used by the add event webserver
-    :return: None
-    """
-    _TesLibInstance.get_instance().initialise(ip_address, port)
-
-
-def reset_event_store():
-    """Reset the test event store removing all event. This function will call cleanup followed by
-    initialise if it fails to reset the event store.
-
-    Calling this function without first calling initialise will have no effect
-
-    :return: None
-    """
-    _TesLibInstance.get_instance().reset()
-
-
-def cleanup():
-    """Cleanup the library - this will stop the event store and webserver processes
-
-    Calling this function multiple times without calling initialise between will have no effect
-
-    :return: None
-    """
-    _TesLibInstance.get_instance().cleanup()
